;=============
;Alpha Effects
;=============

;This demo illustrates some alpha blending effects. You should 
;understand how to use 3D-enabled images before you play around 
;with this. Check out the Draw3DImage.bb demo first.

;The two alpha-blending capabilities being illustrated are:

;(1) Vertex Alpha: You can vary the alpha blending across the face
;of a 3D image by setting different alpha levels for each of the four
;corners. You can do this by using the AlphaVertexBB() command. This
;technique is illustrated by the mage standing in front of the wall,
;where the bottom has been made more opaque, with decreasing alpha
;as you proceed toward the top of the image.

;(2) Alpha Texturing: Alpha texturing allows you to preset the level
;of alpha blending for each pixel in an image. To do this, you must load  
;or create two normal 2D images. The first image is the image itself, 
;with no alpha information. The second is a grey-scale image of the same
;size that contains information about alpha-blending to be used.
;	The darker (more black) a pixel is in the second image, the
;lower the alpha will be in the final image. Black pixels will be
;totally transparent (alpha = 0), while white pixels will be totally
;opaque (alpha = 255). If for some reason you don't use a greyscale
;image, please note that it is the red value of the 2nd image that is
;being used to represent the alpha in the final image. For examples
;of alpha images, check out the images in the graphics folder that 
;end with "_a".
;	An alpha-textured image is created by combining these two images
;with the CreateAlphaImageBB() command. In this demo, the two alpha
;textured images are the mage that moves when you move the mouse
;(check out the shadow) and the fire. Try moving the mage behind the
;fire and observe the varying alpha depending upon how close to the
;center of the flame you are.
;	Please note, however, that alpha texturing may not work right in 
;16 bit mode on some older PCs. For maximum compatibility, use 32-bit 
;dsplay mode (which uses a lot of video memory and may be slower on
;older machines, unfortunately), or try emulating alpha textures by
;using two or more ordinary 3D-enabled images with differing alpha
;that are layered on top of one another to represent a single image.


Include "../ExtendedBlitzLib.bb"
dllFileName$ = "../Blitz2DDll.dll" ;optional (if file not in same directory)
GraphicsBB(800,600,32) ;alpha textures may not work on some older machines in 16 bit

;Load simple 2D ground tiles
Dim tiles(4)
For x = 0 To 3
	tiles(x) = LoadImageBB("graphics/dirt 00"+x+".bmp")
Next
Dim tileArray(16,12)
For x = 0 To 15
For y = 0 To 11
	tileArray(x,y) = Rand(4)-1
Next
Next
platform = LoadImageBB("graphics/platform.bmp")
wall = LoadImageBB("graphics/wall 1.bmp")
MaskImageBB(wall,255,255,255)

;Load alpha-textured mage with an alpha shadow
AutoMidHandleBB(True)
mage = LoadImageBB("graphics/mage.bmp")
alphaTexture = LoadImageBB("graphics/mage_a.bmp")
mage3D = CreateAlphaImageBB(mage,alphaTexture)
FreeImageBB(mage) ;don't need this anymore
FreeImageBB(alphaTexture) ;don't need this anymore

;Create an alpha-textured, animated, 3D flame
Dim flame3D(3)
For x = 0 To 2
	flame = LoadImageBB("graphics/flame"+x+".bmp")
	alphaTexture = LoadImageBB("graphics/flame"+x+"_a.bmp")
	flame3D(x) = CreateAlphaImageBB(flame,alphaTexture)
	FreeImageBB(flame) ;don't need this anymore
	FreeImageBB(alphaTexture) ;don't need this anymore
Next	

;Use the AlphaVertexBB command to set the alpha for the 
;image's four vertices. In this case, the bottom of the image is
;solid and it fades toward the top.
;Note: the first vertex is the upper left corner of the image.
;The other three run in clockwise order from there.
vertexAlphaMage = Load3DImageBB("graphics/mage.bmp")
AlphaVertexBB(vertexAlphaMage,0,0,255,255)
MaskImageBB(vertexAlphaMage,71,71,71)

;Main loop
While Not KeyDown(1)

	;Draw ground and walls
	For x = 0 To 15
	For y = 0 To 11
		DrawBlockBB(tiles(tileArray(x,y)),50*x,50*y)
	Next
	Next
	DrawBlockBB (platform,500,200)
	DrawImageBB (wall,250,150)	
	DrawImageBB (wall,150,200)
	
	;Draw the mage with an alpha textured shadow
	Draw3DImageBB(mage3D,mousexbb(),mouseybb())		

	;Draw another mage using vertex alpha.
	Draw3DImageBB(vertexAlphaMage,250,250)		

	;Draw alpha-textured, animated flame
	frameloops = frameloops + 1
	If frameloops = 8
		frameloops = 0
		frame = frame + 1
		If frame = 3 Then frame = 0
	End If					
	Draw3DImageBB(flame3D(frame),400,350)

	FlipBB()
Wend

EndGraphicsBB()
End